# -*- coding: utf-8 -*-
# Copyright (c) The python-semanticversion project
# This code is distributed under the two-clause BSD License.


from .base import compare, match, validate, SimpleSpec, NpmSpec, Spec, SpecItem, Version


__author__ = "Raphaël Barrois <raphael.barrois+semver@polytechnique.org>"
__version__ = '2.8.5'
